@@ -18,31 +18,14 @@ class Mongodb(Storage):
 
         self.db = self.connection[self.database]
 
-    def get_users(self):
-        res = []
-        for user in self.db.users.find():
-            res.append(user['username'])
-        return res
+    def get_password(self):
+        password = self.get_setting('password')
+        if password:
+            return password
+        return False
 
-    def add_user(self, username, password):
-        return str(self.db.users.save({'username': username,
-                                       'password': password}))
-
-    def remove_user(self, username):
-        user = self.db.users.find_one({'username': username})
-        if user:
-            self.db.users.remove(user['_id'])
-
-    def get_password(self, username):
-        user = self.db.users.find_one({'username': username})
-        if user:
-            return user['password']
-        return None
-
-    def set_password(self, username, password):
-        self.remove_user(username)
-        return str(self.db.users.save({'username': username,
-                                       'password': password}))
+    def set_password(self, password):
+        return self.set_setting('password', self._hash_string(password))
 
     def set_feed_setting(self, feed_id, setting_type, value):
         setting = self.db.feedsettings.find_one({'feed_id': feed_id, 'setting_type': setting_type})
@@ -137,13 +120,13 @@ class Mongodb(Storage):
         return str(self.db.stories.save(content))
 
     def get_story_by_id(self, _id):
-        story = self.db.stories.find_one(ObjectId(_id))
+        story = self.db.stories.find_one({'_id': ObjectId(_id)})
         if story:
             story['_id'] = str(story['_id'])
         return story
 
-    def get_story_by_title(self, title):
-        story = self.db.stories.find_one({'title': title})
+    def get_story_by_title(self, feed_id, title):
+        story = self.db.stories.find_one({'title': title, 'feed_id': feed_id})
         if story:
             story['_id'] = str(story['_id'])
         return story
